@@ -114,8 +114,10 @@ bool DEnumeratorPrivate::createEnumerator(const QUrl &url, QPointer<DEnumeratorP
 void DEnumeratorPrivate::checkAndResetCancel()
 {
     if (cancellable) {
-        g_object_unref(cancellable);
-        cancellable = nullptr;
+        if (!g_cancellable_is_cancelled(cancellable))
+            g_cancellable_cancel(cancellable);
+        g_cancellable_reset(cancellable);
+        return;
     }
     cancellable = g_cancellable_new();
 }
