@@ -36,18 +36,33 @@ private:
     void initializeIndexing();
 
     // 执行内容搜索
-    SearchResultList performContentSearch(const SearchQuery &query);
+    void performContentSearch(const SearchQuery &query);
 
     // 构建Lucene查询
     Lucene::QueryPtr buildLuceneQuery(const SearchQuery &query, const Lucene::AnalyzerPtr &analyzer);
+    // Helper for simple queries (original logic for "contents" field)
+    Lucene::QueryPtr buildSimpleContentsQuery(
+            const SearchQuery &query,
+            const Lucene::QueryParserPtr &contentsParser);
+
+    // Helper for "standard" boolean logic (original logic for "contents" field, handles AND/OR)
+    Lucene::QueryPtr buildStandardBooleanContentsQuery(
+            const SearchQuery &query,
+            const Lucene::QueryParserPtr &contentsParser);
+
+    // Helper for "advanced" mixed AND logic (searches "contents" and "filename")
+    Lucene::QueryPtr buildAdvancedAndQuery(
+            const SearchQuery &query,   // Operator is implicitly AND
+            const Lucene::QueryParserPtr &contentsParser,
+            const Lucene::AnalyzerPtr &analyzer);   // Analyzer is needed to create filenameParser
 
     // 处理搜索结果
-    SearchResultList processSearchResults(const Lucene::IndexSearcherPtr &searcher,
-                                          const Lucene::Collection<Lucene::ScoreDocPtr> &scoreDocs);
+    void processSearchResults(const Lucene::IndexSearcherPtr &searcher,
+                              const Lucene::Collection<Lucene::ScoreDocPtr> &scoreDocs);
 
     QString m_indexDir;
-    std::atomic<bool> m_searching { false };
     Lucene::QueryPtr m_currentQuery;   // 存储当前查询
+    QStringList m_keywords;
 };
 
 DFM_SEARCH_END_NS
