@@ -13,7 +13,7 @@ DFM_SEARCH_BEGIN_NS
 
 /**
  * @brief The SearchOptionsData class provides the private implementation for SearchOptions
- * 
+ *
  * This class implements the PIMPL pattern for SearchOptions, containing all the
  * actual data members and implementation details.
  */
@@ -25,20 +25,16 @@ public:
      */
     SearchOptionsData();
 
-    /**
-     * @brief Copy constructor
-     * @param other The SearchOptionsData object to copy from
-     */
-    SearchOptionsData(const SearchOptionsData &other);
-
     // Public data fields
-    SearchMethod method;           ///< The search method to use
-    bool caseSensitive;           ///< Whether search is case sensitive
-    QString searchPath;           ///< The path to search in
-    bool includeHidden;           ///< Whether to include hidden files
-    int maxResults;               ///< Maximum number of results to return
+    SearchMethod method;   ///< The search method to use
+    bool caseSensitive;   ///< Whether search is case sensitive
+    QString searchPath;   ///< The path to search in
+    QStringList searchExcludedPaths;   ///< excluded search paths.
+    bool includeHidden;   ///< Whether to include hidden files
+    int maxResults;   ///< Maximum number of results to return
     QVariantHash customOptions;   ///< Custom search options
-    bool enableResultFound;       ///< Whether to enable result found notifications
+    bool resultFoundEnabled;   ///< Whether to enable result found notifications
+    int syncSearchTimeoutSecs { 60 };
 };
 
 DFM_SEARCH_END_NS
