@@ -13,6 +13,8 @@
 #include <QDebug>
 #include <QElapsedTimer>
 
+#include "3rdparty/fulltext/chineseanalyzer.h"
+
 DFM_SEARCH_BEGIN_NS
 
 //--------------------------------------------------------------------
@@ -25,13 +27,37 @@ QueryBuilder::QueryBuilder()
 
 Lucene::String QueryBuilder::processString(const QString &str, bool caseSensitive) const
 {
-    String unicodeStr = StringUtils::toUnicode(str.toStdString());
-    if (caseSensitive) {
-        return unicodeStr;
-    } else {
-        StringUtils::toLower(unicodeStr);
-        return unicodeStr;
+    // Step 1: 转成 std::wstring
+    std::wstring input = str.toStdWString();
+
+    // Step 2: 需要转义的 Lucene 特殊字符（按 Lucene 语法）
+    static const std::wstring specialChars = L"+-&&||!(){}[]^\"~*?:\\/";
+
+    std::wstring escaped;
+    escaped.reserve(input.size() * 2);   // 预留空间，提高性能
+
+    for (wchar_t ch : input) {
+        // 如果是 Lucene 特殊字符，就在前面加 '\'
+        if (specialChars.find(ch) != std::wstring::npos) {
+            escaped += L'\\';
+        }
+        escaped += ch;
     }
+
+    // Step 3: 转成 Lucene::String（Lucene++ 使用的是 UTF-8）
+    QString tempQString = QString::fromStdWString(escaped);
+    QByteArray utf8Bytes = tempQString.toUtf8();
+    Lucene::String luceneStr = Lucene::StringUtils::toUnicode(std::string(utf8Bytes.constData(), utf8Bytes.length()));
+    if (luceneStr.empty()) {
+        luceneStr = Lucene::StringUtils::toUnicode(str.toStdString());
+    }
+
+    // Step 4: 如果不区分大小写就转小写（Lucene::String 是 Unicode）
+    if (!caseSensitive) {
+        Lucene::StringUtils::toLower(luceneStr);
+    }
+
+    return luceneStr;
 }
 
 Lucene::QueryPtr QueryBuilder::buildTypeQuery(const QStringList &types) const
@@ -55,6 +81,27 @@ Lucene::QueryPtr QueryBuilder::buildTypeQuery(const QStringList &types) const
     return typeQuery;
 }
 
+Lucene::QueryPtr QueryBuilder::buildExtQuery(const QStringList &extensions) const
+{
+    if (extensions.isEmpty()) {
+        return nullptr;
+    }
+
+    BooleanQueryPtr extQuery = newLucene<BooleanQuery>();
+
+    for (const QString &ext : extensions) {
+        QString cleanExt = ext.trimmed().toLower();
+        if (!cleanExt.isEmpty()) {
+            QueryPtr termQuery = newLucene<TermQuery>(
+                    newLucene<Term>(L"file_ext",
+                                    StringUtils::toUnicode(cleanExt.toStdString())));
+            extQuery->add(termQuery, BooleanClause::SHOULD);
+        }
+    }
+
+    return extQuery;
+}
+
 Lucene::QueryPtr QueryBuilder::buildPinyinQuery(const QStringList &pinyins, SearchQuery::BooleanOperator op) const
 {
     if (pinyins.isEmpty()) {
@@ -65,7 +112,7 @@ Lucene::QueryPtr QueryBuilder::buildPinyinQuery(const QStringList &pinyins, Sear
 
     for (const QString &pinyin : pinyins) {
         QString cleanPinyin = pinyin.trimmed().toLower();
-        if (!cleanPinyin.isEmpty() && SearchUtility::isPurePinyin(cleanPinyin)) {
+        if (!cleanPinyin.isEmpty() && Global::isPinyinSequence(cleanPinyin)) {
             QueryPtr termQuery = newLucene<WildcardQuery>(
                     newLucene<Term>(L"pinyin",
                                     StringUtils::toUnicode(QString("*%1*").arg(cleanPinyin).toStdString())));
@@ -76,60 +123,37 @@ Lucene::QueryPtr QueryBuilder::buildPinyinQuery(const QStringList &pinyins, Sear
     return pinyinQuery;
 }
 
-Lucene::QueryPtr QueryBuilder::buildFuzzyQuery(const QString &keyword, bool caseSensitive) const
+Lucene::QueryPtr QueryBuilder::buildCommonQuery(const QString &keyword, bool caseSensitive, const Lucene::AnalyzerPtr &analyzer, bool allowWildcard) const
 {
-    if (keyword.isEmpty()) {
+    if (keyword.isEmpty() || !analyzer) {
         return nullptr;
     }
 
-    BooleanQueryPtr booleanQuery = newLucene<BooleanQuery>();
-    booleanQuery->setMaxClauseCount(1024);
+    Lucene::QueryParserPtr parser = newLucene<Lucene::QueryParser>(
+            Lucene::LuceneVersion::LUCENE_CURRENT,
+            L"file_name",
+            analyzer);
 
-    QStringList terms = keyword.split(' ', Qt::SkipEmptyParts);
-    for (const QString &term : terms) {
-        if (term.isEmpty()) continue;
-
-        BooleanQueryPtr termQuery = newLucene<BooleanQuery>();
-        String exactTerm = processString(term, caseSensitive);
-
-        // 精确匹配
-        QueryPtr exactQuery = newLucene<TermQuery>(newLucene<Term>(L"file_name", exactTerm));
-        exactQuery->setBoost(3.0);
-        termQuery->add(exactQuery, BooleanClause::SHOULD);
-
-        // 前缀匹配
-        if (term.length() > 2) {
-            QueryPtr prefixQuery = newLucene<PrefixQuery>(newLucene<Term>(L"file_name", exactTerm));
-            prefixQuery->setBoost(2.0);
-            termQuery->add(prefixQuery, BooleanClause::SHOULD);
-        }
-
-        // 通配符匹配
-        if (term.length() > 3) {
-            for (int i = 1; i < term.length() - 1; i++) {
-                QString fuzzyPattern = term.left(i) + "*" + term.mid(i + 1);
-                String wildcardTerm = processString(fuzzyPattern, caseSensitive);
-                QueryPtr wildcardQuery = newLucene<WildcardQuery>(newLucene<Term>(L"file_name", wildcardTerm));
-                wildcardQuery->setBoost(1.0);
-                termQuery->add(wildcardQuery, BooleanClause::SHOULD);
-            }
-        }
-
-        // 包含匹配
-        String containsTerm = L"*" + exactTerm + L"*";
-        QueryPtr containsQuery = newLucene<WildcardQuery>(newLucene<Term>(L"file_name", containsTerm));
-        containsQuery->setBoost(1.5);
-        termQuery->add(containsQuery, BooleanClause::SHOULD);
-
-        booleanQuery->add(termQuery, BooleanClause::MUST);
+    if (allowWildcard) {
+        parser->setAllowLeadingWildcard(true);
     }
 
-    return booleanQuery;
+    return parser->parse(processString(keyword, caseSensitive));
 }
 
-Lucene::QueryPtr QueryBuilder::buildBooleanQuery(const QStringList &terms, bool caseSensitive, SearchQuery::BooleanOperator op) const
+Lucene::QueryPtr QueryBuilder::buildSimpleQuery(const QString &keyword, bool caseSensitive, const Lucene::AnalyzerPtr &analyzer) const
 {
-    if (terms.isEmpty()) {
+    return buildCommonQuery(keyword, caseSensitive, analyzer, false);
+}
+
+Lucene::QueryPtr QueryBuilder::buildWildcardQuery(const QString &keyword, bool caseSensitive, const Lucene::AnalyzerPtr &analyzer) const
+{
+    return buildCommonQuery(keyword, caseSensitive, analyzer, true);
+}
+
+Lucene::QueryPtr QueryBuilder::buildBooleanQuery(const QStringList &terms, bool caseSensitive, SearchQuery::BooleanOperator op, const Lucene::AnalyzerPtr &analyzer) const
+{
+    if (terms.isEmpty() || !analyzer) {
         return nullptr;
     }
 
@@ -138,37 +162,16 @@ Lucene::QueryPtr QueryBuilder::buildBooleanQuery(const QStringList &terms, bool
 
     for (const QString &term : terms) {
         if (!term.isEmpty()) {
-            String termStr = L"*" + processString(term, caseSensitive) + L"*";
-            TermPtr termObj = newLucene<Term>(L"file_name", termStr);
-            QueryPtr termQuery = newLucene<WildcardQuery>(termObj);
-            booleanQuery->add(termQuery, op == SearchQuery::BooleanOperator::AND ? BooleanClause::MUST : BooleanClause::SHOULD);
+            QueryPtr termQuery = buildCommonQuery(term, caseSensitive, analyzer, false);
+            if (termQuery) {
+                booleanQuery->add(termQuery, op == SearchQuery::BooleanOperator::AND ? BooleanClause::MUST : BooleanClause::SHOULD);
+            }
         }
     }
 
     return booleanQuery;
 }
 
-Lucene::QueryPtr QueryBuilder::buildWildcardQuery(const QString &keyword, bool caseSensitive) const
-{
-    if (keyword.isEmpty()) {
-        return nullptr;
-    }
-
-    return newLucene<WildcardQuery>(
-            newLucene<Term>(L"file_name",
-                            processString(keyword, caseSensitive)));
-}
-
-Lucene::QueryPtr QueryBuilder::buildSimpleQuery(const QString &keyword, bool caseSensitive) const
-{
-    if (keyword.isEmpty()) {
-        return nullptr;
-    }
-
-    String queryString = L"*" + processString(keyword, caseSensitive) + L"*";
-    return newLucene<WildcardQuery>(newLucene<Term>(L"file_name", queryString));
-}
-
 //--------------------------------------------------------------------
 // IndexManager 实现
 //--------------------------------------------------------------------
@@ -239,7 +242,7 @@ SearcherPtr IndexManager::getSearcher(IndexReaderPtr reader) const
 //--------------------------------------------------------------------
 
 FileNameIndexedStrategy::FileNameIndexedStrategy(const SearchOptions &options, QObject *parent)
-    : FileNameBaseStrategy(options, parent), m_searchCancelled(false), m_count(0), m_total(0)
+    : FileNameBaseStrategy(options, parent)
 {
     m_queryBuilder = std::make_unique<QueryBuilder>();
     m_indexManager = std::make_unique<IndexManager>();
@@ -258,10 +261,8 @@ void FileNameIndexedStrategy::initializeIndexing()
 
 void FileNameIndexedStrategy::search(const SearchQuery &query)
 {
-    m_searchCancelled = false;
+    m_cancelled.store(false);
     m_results.clear();
-    m_count = 0;
-    m_total = 0;
 
     if (!QFileInfo::exists(m_indexDir)) {
         emit errorOccurred(SearchError(SearchErrorCode::InternalError));
@@ -289,35 +290,38 @@ void FileNameIndexedStrategy::search(const SearchQuery &query)
 void FileNameIndexedStrategy::performIndexSearch(const SearchQuery &query, const FileNameOptionsAPI &api)
 {
     bool caseSensitive = m_options.caseSensitive();
-    QString searchPath = m_options.searchPath();
+    const QString &searchPath = m_options.searchPath();
+    const QStringList &searchExcludedPaths = m_options.searchExcludedPaths();
 
     QStringList fileTypes = api.fileTypes();
+    QStringList fileExtensions = api.fileExtensions();
     bool pinyinEnabled = api.pinyinEnabled();
 
     // 1. 确定搜索类型
-    SearchType searchType = determineSearchType(query, pinyinEnabled, fileTypes);
+    SearchType searchType = determineSearchType(query, pinyinEnabled, fileTypes, fileExtensions);
 
     // 2. 构建查询
-    IndexQuery indexQuery = buildIndexQuery(query, searchType, caseSensitive, pinyinEnabled, fileTypes);
+    IndexQuery indexQuery = buildIndexQuery(query, searchType, caseSensitive, pinyinEnabled, fileTypes, fileExtensions);
 
     // 3. 执行查询并处理结果
-    executeIndexQuery(indexQuery, searchPath);
+    executeIndexQuery(indexQuery, searchPath, searchExcludedPaths);
 }
 
 FileNameIndexedStrategy::SearchType FileNameIndexedStrategy::determineSearchType(
         const SearchQuery &query,
         bool pinyinEnabled,
-        const QStringList &fileTypes) const
+        const QStringList &fileTypes,
+        const QStringList &fileExtensions) const
 {
     QString keyword = query.keyword();
     bool hasKeyword = !keyword.isEmpty();
     bool hasFileTypes = !fileTypes.isEmpty();
+    bool hasFileExts = !fileExtensions.isEmpty();
     bool isBoolean = (query.type() == SearchQuery::Type::Boolean);
 
     // 检查是否需要组合搜索
-    bool combinedWithTypes = (hasKeyword || isBoolean) && hasFileTypes;
-    bool combinedWithPinyin = isBoolean && pinyinEnabled;
-    if (combinedWithTypes || combinedWithPinyin) {
+    bool combinedWithTypes = (hasKeyword || isBoolean) && (hasFileTypes || hasFileExts);
+    if (combinedWithTypes) {
         return SearchType::Combined;
     }
 
@@ -326,6 +330,11 @@ FileNameIndexedStrategy::SearchType FileNameIndexedStrategy::determineSearchType
         return SearchType::FileType;
     }
 
+    // 空关键词但有文件后缀，使用文件后缀搜索
+    if (!hasKeyword && hasFileExts) {
+        return SearchType::FileExt;
+    }
+
     // 有通配符的搜索
     if (hasKeyword && (keyword.contains('*') || keyword.contains('?'))) {
         return SearchType::Wildcard;
@@ -337,8 +346,8 @@ FileNameIndexedStrategy::SearchType FileNameIndexedStrategy::determineSearchType
     }
 
     // 启用拼音搜索
-    if (pinyinEnabled) {
-        return SearchType::PinyinOnly;
+    if (pinyinEnabled && !isBoolean) {
+        return SearchType::Pinyin;
     }
 
     // 默认简单搜索
@@ -350,12 +359,14 @@ FileNameIndexedStrategy::IndexQuery FileNameIndexedStrategy::buildIndexQuery(
         SearchType searchType,
         bool caseSensitive,
         bool pinyinEnabled,
-        const QStringList &fileTypes)
+        const QStringList &fileTypes,
+        const QStringList &fileExtensions)
 {
     IndexQuery result;
     result.type = searchType;
     result.caseSensitive = caseSensitive;
     result.fileTypes = fileTypes;
+    result.fileExtensions = fileExtensions;
     result.usePinyin = pinyinEnabled;   // 设置拼音搜索标志
 
     switch (searchType) {
@@ -369,23 +380,27 @@ FileNameIndexedStrategy::IndexQuery FileNameIndexedStrategy::buildIndexQuery(
         result.terms = SearchUtility::extractBooleanKeywords(query);
         result.booleanOp = query.type() == SearchQuery::Type::Boolean ? query.booleanOperator() : SearchQuery::BooleanOperator::AND;
         break;
-    case SearchType::PinyinOnly:
+    case SearchType::Pinyin:
         result.terms.append(query.keyword());
         break;
     case SearchType::FileType:
         result.fileTypes = fileTypes;
         break;
+    case SearchType::FileExt:
+        result.fileExtensions = fileExtensions;
+        break;
     case SearchType::Combined:
         result.terms = query.type() == SearchQuery::Type::Boolean ? SearchUtility::extractBooleanKeywords(query) : QStringList { query.keyword() };
         result.booleanOp = query.type() == SearchQuery::Type::Boolean ? query.booleanOperator() : SearchQuery::BooleanOperator::AND;
         result.combineWithFileType = !fileTypes.isEmpty();
+        result.combineWithFileExt = !fileExtensions.isEmpty();
         break;
     }
 
     return result;
 }
 
-void FileNameIndexedStrategy::executeIndexQuery(const IndexQuery &query, const QString &searchPath)
+void FileNameIndexedStrategy::executeIndexQuery(const IndexQuery &query, const QString &searchPath, const QStringList &searchExcludedPaths)
 {
     // 获取索引目录
     FSDirectoryPtr directory = m_indexManager->getIndexDirectory(m_indexDir);
@@ -437,14 +452,13 @@ void FileNameIndexedStrategy::executeIndexQuery(const IndexQuery &query, const Q
     try {
         int32_t maxResults = m_options.maxResults() > 0 ? m_options.maxResults() : reader->numDocs();
         searchResults = searcher->search(luceneQuery, maxResults);
-        m_total = searchResults->totalHits;
     } catch (const LuceneException &e) {
         qWarning() << "Search execution error:" << QString::fromStdWString(e.getError());
         emit errorOccurred(SearchError(SearchErrorCode::InternalError));
         return;
     }
 
-    qInfo() << "Search execution time:" << searchTimer.elapsed() << "ms";
+    qInfo() << "Filename search execution time:" << searchTimer.elapsed() << "ms";
 
     // Measure the time taken to process search results
     QElapsedTimer resultTimer;
@@ -453,7 +467,8 @@ void FileNameIndexedStrategy::executeIndexQuery(const IndexQuery &query, const Q
     m_results.reserve(docsSize);
     // 实时处理搜索结果
     for (int i = 0; i < docsSize; i++) {
-        if (m_searchCancelled) {
+        if (m_cancelled.load()) {
+            qInfo() << "Filename search cancelled";
             break;
         }
 
@@ -466,6 +481,16 @@ void FileNameIndexedStrategy::executeIndexQuery(const IndexQuery &query, const Q
                 continue;
             }
 
+            if (std::any_of(searchExcludedPaths.cbegin(), searchExcludedPaths.cend(),
+                            [&path](const auto &excluded) { return path.startsWith(excluded); })) {
+                continue;
+            }
+
+            if (Q_LIKELY(!m_options.includeHidden())) {
+                if (QString::fromStdWString(doc->get(L"is_hidden")).toLower() == "y")
+                    continue;
+            }
+
             // 处理搜索结果
             if (Q_UNLIKELY(m_options.resultFoundEnabled())) {
                 QString type = QString::fromStdWString(doc->get(L"file_type"));
@@ -478,15 +503,13 @@ void FileNameIndexedStrategy::executeIndexQuery(const IndexQuery &query, const Q
                 m_results.append(result);
             }
 
-            m_count++;
-
         } catch (const LuceneException &e) {
             qWarning() << "Error processing result:" << QString::fromStdWString(e.getError());
             continue;
         }
     }
 
-    qInfo() << "Result processing time:" << resultTimer.elapsed() << "ms";
+    qInfo() << "Filename result processing time:" << resultTimer.elapsed() << "ms";
 }
 
 SearchResult FileNameIndexedStrategy::processSearchResult(const QString &path, const QString &type, const QString &time, const QString &size)
@@ -509,11 +532,12 @@ Lucene::QueryPtr FileNameIndexedStrategy::buildLuceneQuery(const IndexQuery &que
 {
     BooleanQueryPtr finalQuery = newLucene<BooleanQuery>();
     bool hasValidQuery = false;
+    AnalyzerPtr analyzer = newLucene<ChineseAnalyzer>();
 
     switch (query.type) {
     case SearchType::Simple:
         if (!query.terms.isEmpty()) {
-            QueryPtr simpleQuery = m_queryBuilder->buildSimpleQuery(query.terms.first(), query.caseSensitive);
+            QueryPtr simpleQuery = m_queryBuilder->buildSimpleQuery(query.terms.first(), query.caseSensitive, analyzer);
             if (simpleQuery) {
                 finalQuery->add(simpleQuery, BooleanClause::MUST);
                 hasValidQuery = true;
@@ -522,7 +546,7 @@ Lucene::QueryPtr FileNameIndexedStrategy::buildLuceneQuery(const IndexQuery &que
         break;
     case SearchType::Wildcard:
         if (!query.terms.isEmpty()) {
-            QueryPtr wildcardQuery = m_queryBuilder->buildWildcardQuery(query.terms.first(), query.caseSensitive);
+            QueryPtr wildcardQuery = m_queryBuilder->buildWildcardQuery(query.terms.first(), query.caseSensitive, analyzer);
             if (wildcardQuery) {
                 finalQuery->add(wildcardQuery, BooleanClause::MUST);
                 hasValidQuery = true;
@@ -531,20 +555,36 @@ Lucene::QueryPtr FileNameIndexedStrategy::buildLuceneQuery(const IndexQuery &que
         break;
     case SearchType::Boolean:
         if (!query.terms.isEmpty()) {
-            QueryPtr booleanQuery = m_queryBuilder->buildBooleanQuery(query.terms, query.caseSensitive, query.booleanOp);
+            BooleanQueryPtr booleanQuery = buildBooleanTermsQuery(query, analyzer);
             if (booleanQuery) {
                 finalQuery->add(booleanQuery, BooleanClause::MUST);
                 hasValidQuery = true;
             }
         }
         break;
-    case SearchType::PinyinOnly:
+    case SearchType::Pinyin:
         if (!query.terms.isEmpty()) {
-            QueryPtr pinyinQuery = m_queryBuilder->buildPinyinQuery(query.terms);
-            if (pinyinQuery) {
-                finalQuery->add(pinyinQuery, BooleanClause::MUST);
+            BooleanQueryPtr combinedQuery = newLucene<BooleanQuery>();
+
+            // 添加拼音查询
+            if (Global::isPinyinSequence(query.terms.first())) {
+                QueryPtr pinyinQuery = m_queryBuilder->buildPinyinQuery(query.terms);
+                if (pinyinQuery) {
+                    combinedQuery->add(pinyinQuery, BooleanClause::SHOULD);
+                    hasValidQuery = true;
+                }
+            }
+
+            // 添加普通关键词查询
+            QueryPtr simpleQuery = m_queryBuilder->buildSimpleQuery(query.terms.first(), query.caseSensitive, analyzer);
+            if (simpleQuery) {
+                combinedQuery->add(simpleQuery, BooleanClause::SHOULD);
                 hasValidQuery = true;
             }
+
+            if (hasValidQuery) {
+                finalQuery->add(combinedQuery, BooleanClause::MUST);
+            }
         }
         break;
     case SearchType::FileType:
@@ -556,28 +596,21 @@ Lucene::QueryPtr FileNameIndexedStrategy::buildLuceneQuery(const IndexQuery &que
             }
         }
         break;
-    case SearchType::Combined:
-        if (!query.terms.isEmpty()) {
-            BooleanQueryPtr combinedQuery = newLucene<BooleanQuery>();
-
-            // 构建布尔关键词查询
-            QueryPtr keywordQuery = m_queryBuilder->buildBooleanQuery(query.terms, query.caseSensitive, query.booleanOp);
-            if (keywordQuery) {
-                combinedQuery->add(keywordQuery, BooleanClause::SHOULD);
+    case SearchType::FileExt:
+        if (!query.fileExtensions.isEmpty()) {
+            QueryPtr extQuery = m_queryBuilder->buildExtQuery(query.fileExtensions);
+            if (extQuery) {
+                finalQuery->add(extQuery, BooleanClause::MUST);
                 hasValidQuery = true;
             }
-
-            // 添加拼音查询
-            if (query.usePinyin) {
-                QueryPtr pinyinQuery = m_queryBuilder->buildPinyinQuery(query.terms, query.booleanOp);
-                if (pinyinQuery) {
-                    combinedQuery->add(pinyinQuery, BooleanClause::SHOULD);
-                    hasValidQuery = true;
-                }
-            }
-
-            if (hasValidQuery) {
+        }
+        break;
+    case SearchType::Combined:
+        if (!query.terms.isEmpty()) {
+            BooleanQueryPtr combinedQuery = buildBooleanTermsQuery(query, analyzer);
+            if (combinedQuery) {
                 finalQuery->add(combinedQuery, BooleanClause::MUST);
+                hasValidQuery = true;
             }
         }
 
@@ -589,15 +622,61 @@ Lucene::QueryPtr FileNameIndexedStrategy::buildLuceneQuery(const IndexQuery &que
                 hasValidQuery = true;
             }
         }
+
+        // 构建文件后缀查询
+        if (query.combineWithFileExt && !query.fileExtensions.isEmpty()) {
+            QueryPtr extQuery = m_queryBuilder->buildExtQuery(query.fileExtensions);
+            if (extQuery) {
+                finalQuery->add(extQuery, BooleanClause::MUST);
+                hasValidQuery = true;
+            }
+        }
         break;
     }
 
     return hasValidQuery ? finalQuery : nullptr;
 }
 
+BooleanQueryPtr FileNameIndexedStrategy::buildBooleanTermsQuery(const IndexQuery &query, const AnalyzerPtr &analyzer) const
+{
+    // 创建布尔查询
+    BooleanQueryPtr booleanQuery = newLucene<BooleanQuery>();
+    bool hasValidQuery = false;
+
+    // 对每个搜索词创建子查询
+    for (const QString &term : query.terms) {
+        BooleanQueryPtr termQuery = newLucene<BooleanQuery>();
+        bool termHasQuery = false;
+
+        // 添加普通关键词查询
+        QueryPtr keywordQuery = m_queryBuilder->buildSimpleQuery(term, query.caseSensitive, analyzer);
+        if (keywordQuery) {
+            termQuery->add(keywordQuery, BooleanClause::SHOULD);
+            termHasQuery = true;
+        }
+
+        // 添加拼音查询
+        if (query.usePinyin && Global::isPinyinSequence(term)) {
+            QueryPtr pinyinQuery = m_queryBuilder->buildPinyinQuery(QStringList { term });
+            if (pinyinQuery) {
+                termQuery->add(pinyinQuery, BooleanClause::SHOULD);
+                termHasQuery = true;
+            }
+        }
+
+        // 将当前词的查询添加到最终查询中，维持原始bool逻辑
+        if (termHasQuery) {
+            booleanQuery->add(termQuery, query.booleanOp == SearchQuery::BooleanOperator::AND ? BooleanClause::MUST : BooleanClause::SHOULD);
+            hasValidQuery = true;
+        }
+    }
+
+    return hasValidQuery ? booleanQuery : nullptr;
+}
+
 void FileNameIndexedStrategy::cancel()
 {
-    m_searchCancelled = true;
+    m_cancelled.store(true);
 }
 
 DFM_SEARCH_END_NS
